@@ -69,13 +69,13 @@ inv
 
 
 
-//! delayed matrix inverse (symmetric matrices)
+//! delayed matrix inverse (symmetric positive definite matrices)
 template<typename T1>
 arma_inline
-const Op<T1, op_inv_sym>
+const Op<T1, op_inv_sympd>
 inv
   (
-  const Op<T1, op_symmat>& X,
+  const Op<T1, op_sympd>& X,
   const bool slow = false,
   const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
   )
@@ -84,7 +84,35 @@ inv
   arma_ignore(slow);
   arma_ignore(junk);
   
-  return Op<T1, op_inv_sym>(X.m, X.aux_u32_a, 0);
+  return Op<T1, op_inv_sympd>(X.m, 0, 0);
+  }
+
+
+
+template<typename T1>
+inline
+bool
+inv
+  (
+         Mat<typename T1::elem_type>&    out,
+  const Base<typename T1::elem_type,T1>& X,
+  const bool slow = false,
+  const typename arma_blas_type_only<typename T1::elem_type>::result* junk = 0
+  )
+  {
+  arma_extra_debug_sigprint();
+  arma_ignore(junk);
+  
+  try
+    {
+    out = inv(X,slow);
+    }
+  catch(std::runtime_error&)
+    {
+    return false;
+    }
+  
+  return true;
   }
 
 
