@@ -1,5 +1,5 @@
-// Copyright (C) 2008-2010 NICTA (www.nicta.com.au)
-// Copyright (C) 2008-2010 Conrad Sanderson
+// Copyright (C) 2008-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2008-2011 Conrad Sanderson
 // 
 // This file is part of the Armadillo C++ library.
 // It is provided without any warranty of fitness
@@ -41,9 +41,11 @@ min(const Row<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "min(): given vector has no elements" );
+  const u32 A_n_elem = A.n_elem;
   
-  return op_min::direct_min(A.mem, A.n_elem);
+  arma_debug_check( (A_n_elem == 0), "min(): given object has no elements" );
+  
+  return op_min::direct_min(A.mem, A_n_elem);
   }
 
 
@@ -57,9 +59,11 @@ min(const Col<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "min(): given vector has no elements" );
+  const u32 A_n_elem = A.n_elem;
   
-  return op_min::direct_min(A.mem, A.n_elem);
+  arma_debug_check( (A_n_elem == 0), "min(): given object has no elements" );
+  
+  return op_min::direct_min(A.mem, A_n_elem);
   }
 
 
@@ -81,9 +85,11 @@ min(const Op<T1, op_min>& in)
   const unwrap<T1> tmp1(in.m);
   const Mat<eT>& X = tmp1.M;
   
-  arma_debug_check( (X.n_elem == 0), "min(): given matrix has no elements" );
+  const u32 X_n_elem = X.n_elem;
   
-  return op_min::direct_min(X.mem, X.n_elem);
+  arma_debug_check( (X_n_elem == 0), "min(): given object has no elements" );
+  
+  return op_min::direct_min(X.mem, X_n_elem);
   }
 
 
@@ -108,7 +114,7 @@ min(const subview_row<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "min(): given vector has no elements" );
+  arma_debug_check( (A.n_elem == 0), "min(): given object has no elements" );
   
   return op_min::direct_min(A);
   }
@@ -123,9 +129,9 @@ min(const subview_col<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "min(): given vector has no elements" );
+  arma_debug_check( (A.n_elem == 0), "min(): given object has no elements" );
   
-  return op_min::direct_min(A);
+  return op_min::direct_min(A.colptr(0), A.n_rows);
   }
 
 
@@ -138,7 +144,7 @@ min(const diagview<eT>& A)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "min(): given vector has no elements" );
+  arma_debug_check( (A.n_elem == 0), "min(): given object has no elements" );
   
   return op_min::direct_min(A);
   }
@@ -156,7 +162,7 @@ min(const Op<subview<eT>, op_min>& in)
   
   const subview<eT>& X = in.m;
   
-  arma_debug_check( (X.n_elem == 0), "min(): given matrix has no elements" );
+  arma_debug_check( (X.n_elem == 0), "min(): given object has no elements" );
   
   return op_min::direct_min(X);
   }
@@ -173,9 +179,11 @@ min(const subview_elem1<eT,T1>& A)
   
   const Mat<eT> X(A);
   
-  arma_debug_check( (X.n_elem == 0), "min(): given matrix has no elements" );
+  const u32 X_n_elem = X.n_elem;
   
-  return op_min::direct_min(X.mem, X.n_elem);
+  arma_debug_check( (X_n_elem == 0), "min(): given object has no elements" );
+  
+  return op_min::direct_min(X.mem, X_n_elem);
   }
 
 
