@@ -1,5 +1,5 @@
-// Copyright (C) 2009-2010 NICTA (www.nicta.com.au)
-// Copyright (C) 2009-2010 Conrad Sanderson
+// Copyright (C) 2009-2011 NICTA (www.nicta.com.au)
+// Copyright (C) 2009-2011 Conrad Sanderson
 // Copyright (C) 2009-2010 Dimitrios Bouzas
 // 
 // This file is part of the Armadillo C++ library.
@@ -79,11 +79,11 @@ op_cov::direct_cov(Mat< std::complex<T> >& out, const Mat< std::complex<T> >& A,
     {
     const u32 N = A.n_rows;
     const eT norm_val = (norm_type == 0) ? ( (N > 1) ? eT(N-1) : eT(1) ) : eT(N);
-
+    
     const Row<eT> acc = sum(A);
-
-    out = trans(conj(A)) * A;
-    out -= (trans(conj(acc)) * acc)/eT(N);
+    
+    out = trans(A) * A;               // out = strans(conj(A)) * A;
+    out -= (trans(acc) * acc)/eT(N);  // out -= (strans(conj(acc)) * acc)/eT(N);
     out /= norm_val;
     }
   }
